@@ -52,18 +52,16 @@ let the user set that location.
 
 =cut
 
-use base qw(Exporter);
+use Exporter qw(import);
 
 __PACKAGE__->run( @ARGV ) unless caller;
 
 use Carp;
 use LWP::Simple qw(get);
 
-# http://standards.ieee.org/regauth/oui/oui.txt
-
 our $Cached = {};
 
-our $VERSION = '1.19_03';
+our $VERSION = '1.24_01';
 
 =item run( @macs )
 
@@ -85,11 +83,14 @@ sub run {
 
 	foreach my $arg ( @_ ) {
 		my $lines = lookup( $arg );
+		return unless defined $lines;
 
 		unshift @$lines, $arg;
 
 		print join "\n", @$lines, '';
 		}
+
+	return 1;
 	}
 
 =item lookup( MAC )
@@ -194,7 +195,7 @@ MAC.
 sub fetch_oui_from_ieee {
 	my $mac = normalize_mac( shift );
 
-	my $html = get( "http://standards.ieee.org/cgi-bin/ouisearch?$mac" );
+	my $html = get( "https://standards.ieee.org/cgi-bin/ouisearch?$mac" );
 	unless( defined $html ) {
 		carp "Could not fetch data from the IEEE!";
 		return;
@@ -297,13 +298,13 @@ sub parse_oui {
 	return \@lines;
 	}
 
-=item load_cache( [ SOURCE ] )
+=item load_cache( [ SOURCE[, DEST ] ] )
 
 Downloads the current list of all OUIs, parses it with C<parse_oui()>,
 and stores it in C<$Cached> anonymous hash keyed by the OUIs (i.e.
 00-0D-93). The C<fetch_oui()> will use this cache if it exists.
 
-By default, this uses C<http://standards.ieee.org/regauth/oui/oui.txt>, 
+By default, this uses C<https://standards.ieee.org/regauth/oui/oui.txt>, 
 but given an argument, it tries to use that. To load from a local
 file, use the C<file://> scheme.
 
@@ -314,10 +315,27 @@ This previously used DBM::Deep if it was installed, but that was much
 too slow. Instead, if you want persistence, you can play with 
 C<$Net::MAC::Vendor::Cached> yourself.
 
+If you want to store the data fetched for later use, add a destination
+filename to the request. To fetch from the default location and store,
+specify C<undef> as source.
+
 =cut
 
+=item oui_url
+
+Returns the URL of the oui.txt resource. The IEEE likes to move this
+around. This is the default URL that C<load_cache> will use, but you 
+can also 
+
+=cut
+
+sub oui_url {
+	'http://www.ieee.org/netstorage/standards/oui.txt'
+	}
+
 sub load_cache {
-	my $source = shift || "http://standards.ieee.org/regauth/oui/oui.txt";
+	my $source = shift || oui_url();
+	my $dest   = shift;
 
 	my $data = do {
 		if( -e $source ) { # local files
@@ -331,6 +349,16 @@ sub load_cache {
 				return;
 				}
 
+			if ( $dest ) { # store cache
+				if ( open my $fh, '>', $dest ) {
+					print $fh $data;
+					close $fh;
+					} 
+				else { # notify on error, but continue
+					carp "Could not write to '$dest'";
+					}
+				}
+
 			$data;
 			}
 		};
@@ -340,7 +368,8 @@ sub load_cache {
 	# still there. We need to split on a newline
 	# followed by some potentially horizontal whitespace
 	# and another newline
-	my @entries = split /[\t ]*\n[\t ]*\n/, $data;
+	my $CRLF = qr/(?:\r?\n)/;
+	my @entries = split /[\t ]* $CRLF [\t ]* $CRLF/x, $data;
 	shift @entries;
 
 	my $count = '';
@@ -373,7 +402,7 @@ brian d foy C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2004-2013 brian d foy.  All rights reserved.
+Copyright © 2004-2015, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
